@@ -14,18 +14,19 @@ available under the terms of the BSD which accompanies this distribution, and
 is available at U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
+from gi.repository import Gtk as gtk
+from gi.repository import Gdk as gdk
+from gi.repository import Wnck as wnck
+from gi.repository import GConf as gconf
+from gi.repository import GObject
+from gi.repository import Atk as atk
 from gi.repository.Gio import Settings
+
 a11yAppSettings = Settings('org.gnome.desktop.interface')
 
-import pygtk
-pygtk.require('2.0')
-import gtk
-import gobject
-import gtk.gdk
 import os, sys, locale
 from icons import getIcon
 import os
-import atk
 from bookmarks import BookmarkStore
 from accessible_treeview import *
 from node import Node
@@ -33,7 +34,6 @@ from plugin import PluginManager
 from plugin import PluginView
 from tools import Tools
 from i18n import _, N_
-import wnck
 from hotkey_manager import HotkeyManager, HotkeyTreeView
 from about_dialog import AccerciserAboutDialog
 from prefs_dialog import AccerciserPreferencesDialog
@@ -96,7 +96,7 @@ class Main(Tools):
       action = main_actions.get_action(action_name)
       ui_manager.uimanager.add_ui(ui_manager.uimanager.new_merge_id(), 
                                   menu_path, action_name, action_name, 
-                                  gtk.UI_MANAGER_MENUITEM, False)
+                                  gtk.UIManagerItemType.MENUITEM, False)
 
 
     self.last_focused = None
@@ -108,7 +108,7 @@ class Main(Tools):
     '''
     # Tell user if desktop accessibility is disabled.
     self._showNoA11yDialog()
-    gobject.timeout_add(200, self._pumpEvents)
+    GObject.timeout_add(200, self._pumpEvents)
     try:
       pyatspi.Registry.start(async=True, gil=False)
     except KeyboardInterrupt:
@@ -128,20 +128,20 @@ class Main(Tools):
       message = _('Accerciser could not see the applications on your desktop.  '
                   'You must enable desktop accessibility to fix this problem.  '
                   'Do you want to enable it now?')
-      dialog = gtk.MessageDialog(self.window,type=gtk.MESSAGE_ERROR,
-                                 buttons=gtk.BUTTONS_YES_NO, 
+      dialog = gtk.MessageDialog(self.window,type=gtk.MessageType.ERROR,
+                                 buttons=gtk.ButtonsType.YES_NO, 
                                  message_format=message)
       dialog.connect('response', self._onNoA11yResponse)
       dialog.show_all()
 
   def _onNoA11yResponse(self, dialog, response_id):
     dialog.destroy()
-    if response_id == gtk.RESPONSE_YES:
+    if response_id == gtk.ResponseType.YES:
       a11yAppSettings.set_boolean('toolkit-accessibility', True)
       dialog = gtk.MessageDialog(
         self.window,
-        type=gtk.MESSAGE_INFO,
-        buttons=gtk.BUTTONS_OK, 
+        type=gtk.MessageType.INFO,
+        buttons=gtk.ButtonsType.OK, 
         message_format=_('Note: Changes only take effect after logout.'))
       dialog.connect('response', lambda dia, resp: dia.destroy())
       dialog.show_all()
@@ -153,7 +153,7 @@ class Main(Tools):
     self.window.saveState()
     self.plugin_manager.close()
 
-  def _onQuit(self, obj):
+  def _onQuit(self, obj, data=None):
     '''
     Quits the app.
 
@@ -163,7 +163,7 @@ class Main(Tools):
     self._shutDown()
     pyatspi.Registry.stop()
     
-  def _onAbout(self, action):
+  def _onAbout(self, action, data=None):
     '''
     Shows the about dialog.
 
@@ -171,7 +171,7 @@ class Main(Tools):
     @type widget: L{gtk.Widget}
     '''
     about = AccerciserAboutDialog()
-    about.show_all()
+    about.run()
     
   def _onHelp(self, action, page=""):
     '''
@@ -183,12 +183,12 @@ class Main(Tools):
     uri = "ghelp:accerciser"
     if page:
         uri += "?%s" % page
-    gtk.show_uri(gtk.gdk.screen_get_default(),
+    gtk.show_uri(gdk.Screen.get_default(),
                  uri,
                  gtk.get_current_event_time())
     return True
          
-  def _onShowPreferences(self, action):
+  def _onShowPreferences(self, action, data=None):
     '''
     Shows the preferences dialog.
 
